==> haskell-cabal-doctest-1.0.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cabal-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-doctest
version: 1.0.2
id: cabal-doctest-1.0.2-7qDWi4QMBieCUnNAxkUwxe
key: cabal-doctest-1.0.2-7qDWi4QMBieCUnNAxkUwxe
license: BSD3
copyright: (c) 2017 Oleg Grenrus
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/cabal-doctest
synopsis: A Setup.hs helper for doctests running
description:
    Currently (beginning of 2017), there isn'\''t @cabal doctest@
    command. Yet, to properly work doctest needs plenty of configuration.
    This library provides the common bits for writing custom Setup.hs
    See <https://github.com/haskell/cabal/issues/2327 Cabal/2327> for the progress
    of @cabal doctest@, i.e. whether this library is obsolete.
category: Distribution
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Distribution.Extra.Doctest
abi: a2a5161cba8083d034ac86576645dc9e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/cabal-doctest-1.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/cabal-doctest-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/cabal-doctest-1.0.2
hs-libraries: HScabal-doctest-1.0.2-7qDWi4QMBieCUnNAxkUwxe
depends:
    Cabal-1.24.2.0 base-4.9.1.0 directory-1.3.0.0 filepath-1.4.1.1
haddock-interfaces: /usr/share/doc/haskell-cabal-doctest/html/cabal-doctest.haddock
haddock-html: /usr/share/doc/haskell-cabal-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cabal-doctest-1.0.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cabal-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-doctest
version: 1.0.2
id: cabal-doctest-1.0.2-Bl80n9TxTYEBsBCKM9EFAB
key: cabal-doctest-1.0.2-Bl80n9TxTYEBsBCKM9EFAB
license: BSD3
copyright: (c) 2017 Oleg Grenrus
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/cabal-doctest
synopsis: A Setup.hs helper for doctests running
description:
    Currently (beginning of 2017), there isn'\''t @cabal doctest@
    command. Yet, to properly work doctest needs plenty of configuration.
    This library provides the common bits for writing custom Setup.hs
    See <https://github.com/haskell/cabal/issues/2327 Cabal/2327> for the progress
    of @cabal doctest@, i.e. whether this library is obsolete.
category: Distribution
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Distribution.Extra.Doctest
abi: ae131494cbe2d604cdb404307418ef6a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cabal-doctest-1.0.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/cabal-doctest-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/cabal-doctest-1.0.2
hs-libraries: HScabal-doctest-1.0.2-Bl80n9TxTYEBsBCKM9EFAB
depends:
    base-4.10.0.0 Cabal-2.0.0.2 filepath-1.4.1.2 directory-1.3.0.2
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             Cabal-2.0.0.2=967894c66ebadf39b2418a365180d683
             filepath-1.4.1.2=7f2f990ae2114c616de6dfc1a7f18a6e
             directory-1.3.0.2=3638cd3d85711234b23f0c0ec04058d3
haddock-interfaces: /usr/share/doc/haskell-cabal-doctest/html/cabal-doctest.haddock
haddock-html: /usr/share/doc/haskell-cabal-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
